
/**
 * 
 * @param {type} evt
 * @returns {unresolved}
 */
function handleOpenFileSelect(evt) {
    var files = evt.target.files; // FileList object
    if (!files.length) {
        return;
    }
    $("#filename").val(escape(files[0].name));
    var reader = new FileReader();
    reader.onload = function(event)
    {
        $("#rawdata").val(event.target.result);
        OnLoadData();
    };
    reader.readAsText(files[0], "UTF-8");
}
/**
 * 
 * @returns {Array}
 */
function RawDataToGrid()
{
    var datagrid = new Array();
    var str = $("#rawdata").val();
    var rows = str.split("\n");
    for (var i in rows)
    {
        var row = rows[i];
        var cols = row.split("\t");
        datagrid[i] = cols;
    }
    //console.log(datagrid);
    return datagrid;
}


/**
 * 
 * @returns {undefined}
 */
function MakeSpreadSheet()
{

    var alldata = RawDataToGrid();
    var spheader = new Array();
    var spdata = new Array();
    for (var i in alldata[0])
    {
        var tmp = alldata[0][i];
        spheader[i] = trimSlashes(tmp);
    }
    var first = true;
    var rowId = 0;
    for (var i in alldata)
    {
        var cols = alldata[i];
        if (!first)
        {
            spdata[rowId] = new Array();
            for (var ic in cols)
            {
                spdata[rowId][ic] = trimSlashes(cols[ic]);
            }
            rowId++;
        }
        first = false;
    }
    $("#gridcontents").handsontable({
        data: spdata,
        height: 480,
        width: 600,
        colHeaders: spheader,
        columnSorting: false,
        contextMenu: ['row_above', 'row_below', 'remove_row']
    });
}


var previousPoint = null, previousLabel = null;
var monthNames = [_i18n("Jan"), _i18n("Feb"), _i18n("Mar"), _i18n("Apr"), _i18n("May"), _i18n("Jun"), _i18n("Jul"), _i18n("Aug"), _i18n("Sep"), _i18n("Oct"), _i18n("Nov"), _i18n("Dec")];


var ttlock = false;
/**
 * 
 * @returns {undefined}
 */
function MakeChart() {
    var container = $("#gridcontents");
    var handsontable = container.data('handsontable');
    var data = handsontable.getData();
    var gr0 = new Array();
    var gr1 = new Array();



    for (var i in data) {
        gr0[i] = new Array();
        gr0[i][0] = parse_date(data[i][1]);
        gr0[i][1] = (data[i][2]);
    }
    for (var i in data) {
        gr1[i] = new Array();
        gr1[i][0] = parse_date(data[i][1]);
        gr1[i][1] = (data[i][3]);
    }


    var placeholder = $("#placeholder");
    myplot = $.plot("#placeholder", [{
            data: gr0,
            label: _i18n("light", "Aa"),
            lines: {show: true, fill: false},
            points: {show: true}
        }, {
            data: gr1,
            yaxis: 2,
            label: _i18n("temperature", "Aa"),
            lines: {show: true, fill: false},
            points: {show: true}

        }], {
        xaxes: [
            {
                mode: "time",
                timeformat: "%Y-%m-%d %H:%M:%S",
                timezone: "browser",
                axisLabel: _i18n("date", "Aa"),
                axisLabelUseCanvas: true,
                axisLabelFontSizePixels: 12,
                axisLabelFontFamily: 'Verdana, Arial',
                axisLabelPadding: 0
            }
        ],
        yaxes: [
            {
                min: 0,
                color: "black",
                axisLabel: _i18n("units")
            }, {
                // align if we are to the right
                alignTicksWithAxis: 1,
                position: "right",
                axisLabel: "°C",
                axisLabelUseCanvas: true,
                axisLabelFontSizePixels: 12,
                axisLabelFontFamily: 'Verdana, Arial',
                axisLabelPadding: 0
            }],
        legend: {position: "se"},
        zoom: {
            interactive: true
        },
        pan: {
            interactive: true
        },
        grid: {
            hoverable: true,
            borderWidth: 3,
            mouseActiveRadius: 50,
            backgroundColor: {colors: ["#ffffff", "#EDF5FF"]},
            axisMargin: 20
        }
    });


    placeholder.bind('plotpan', function(event, plot) {
        updateStatusbar();
    });

    placeholder.bind('plotzoom', function(event, plot) {
        updateStatusbar();
    });

    //tooltips---------------------------->
    placeholder.bind("plothover", function(event, pos, item) {

        if (item) {
            
            if ((previousLabel != item.series.label) || (previousPoint != item.dataIndex))
            {
                previousPoint = item.dataIndex;
                previousLabel = item.series.label;
                $("#tooltip").remove();

                var x = item.datapoint[0];
                var y = item.datapoint[1];
                var date = formatDateFromUnixTimestamp(x);
                var color = item.series.color;
                //console.log(event);
                //console.log(item.series.yaxis.options.axisLabel);
                if (!ttlock)
                {
                    ttlock = true;
                    window.setTimeout(function() {
                        showTooltip(item.pageX, item.pageY, color,
                                date +
                                "<br /><strong>" + item.series.label + ":</strong>" +
                                "  <strong>" + y + "</strong> " + item.series.yaxis.options.axisLabel);
                        ttlock = false;
                    }, 1000);
                }
            }
        } else {
            window.setTimeout(function() {
                $("#tooltip").remove();
            }, 1000);
            previousPoint = null;
        }

    });
    //tooltips----------------------------<



    updateStatusbar();
}

function showTooltip(x, y, color, contents) {
    $('<div id="tooltip">' + contents + '</div>').css({
        position: 'absolute',
        display: 'none',
        top: y - 40,
        left: x - 120,
        border: '2px solid ' + color,
        padding: '3px',
        'font-size': '9px',
        'border-radius': '5px',
        'background-color': '#fff',
        'font-family': 'Verdana, Arial, Helvetica, Tahoma, sans-serif',
        opacity: 0.9
    }).appendTo("body").fadeIn(200);
}
function updateStatusbar()
{
    var axes = myplot.getAxes();
    $("#statusbar").html(_i18n("data from", "Aa") + ": " + formatDateFromUnixTimestamp(axes.xaxis.min)
            + " " + _i18n("to") + ": " + formatDateFromUnixTimestamp(axes.xaxis.max)
            );
}

function timeFromUnixTimestampToMysqlDate(UNIX_timestamp) {
    var a = new Date(UNIX_timestamp * 1000);
    var months = monthNames;
    var year = a.getFullYear();
    var month = months[a.getMonth()];
    var date = a.getDate();
    var hour = a.getHours();
    var min = a.getMinutes();
    var sec = a.getSeconds();
    var time = date + ' ' + month + ' ' + year + ' ' + AddLeftZero(hour) + ':' + AddLeftZero(min) + ':' + AddLeftZero(sec);
    return time;
}


function formatDateFromUnixTimestamp(date)
{
    var unix_timestamp = parseInt(parseFloat(date) / 1000);
    return timeFromUnixTimestampToMysqlDate(unix_timestamp);
}

function AddLeftZero(n)
{
    if (parseInt(n) <= 9)
        return "0" + n;
    return n;
}

function formatDateFromDateObj(date)
{

    /*
     var ret = "";
     ret = date.getFullYear().toString();
     ret += "-";
     ret += AddLeftZero(date.getMonth());
     ret += "-";
     ret += AddLeftZero(date.getDay());
     ret += " ";
     ret += AddLeftZero(date.getHours());
     ret += ":";
     ret += AddLeftZero(date.getMinutes());
     ret += ":";
     ret += AddLeftZero(date.getSeconds());
     ret += "";
     return ret;*/
}
/**
 * 
 * @returns {undefined}
 */
function OnLoadData()
{

    MakeSpreadSheet();
    MakeChart();

}
/**
 * 
 * @param {type} str
 * @returns {unresolved}
 */
function trimSlashes(str)
{
    str = str.replace(/^"/, "");
    str = str.replace(/"$/, "");
    str = str.replace(/""/, '"');
    return str;
}

function parse_date(string) {
    var date = new Date();
    var parts = String(string).split(/[- :]/);

    date.setFullYear(parts[0]);
    date.setMonth(parts[1] - 1);
    date.setDate(parts[2]);
    date.setHours(parts[3]);
    date.setMinutes(parts[4]);
    date.setSeconds(parts[5]);
    date.setMilliseconds(0);
    return date;
}
function printCurrentDate()
{
    var data = new Date();
    txtDate = formatDateFromDateObj(data);
    document.getElementById("localtime").innerHTML = txtDate;
}
