/**
 * 
 * DXF Library
 * @author Alessandro Vernassa
 */
/**
 * 
 * @returns {DXFLayer}
 */
function DXFLayer()
{
    this.name = "0";
    this.color = "0";
    this.linetype = "CONTINUOUS";
}
/**
 * 
 * @returns {DXF}
 */
function DXF() {
    this.strDXF = "";
    this.layers = new Array();
    this.ShapeString = "";
    /**
     * 
     * @param {type} name
     * @param {type} color
     * @param {type} linetype
     * @returns {undefined}
     */
    this.addLayer = function(name, color, linetype)
    {
        name = (typeof(name) !== 'undefined') ? name : "0";
        color = (typeof(color) !== 'undefined') ? color : "0";
        linetype = (typeof(linetype) !== 'undefined') ? linetype : "CONTINUOUS";
        var tmp = new DXFLayer();
        tmp.name = name;
        tmp.color = color;
        tmp.linetype = linetype;
        this.layers.push(tmp);
    };
    /**
     * 
     * @returns {String}
     */
    this.getString = function()
    {
        var strDXF = "";
        strDXF += this.getHeaderString();
        strDXF += this.getBodyString();
        return strDXF;
    };
    /**
     * 
     * @returns {String}
     */
    this.getHeaderString = function()
    {
        var strDXF = "";
        strDXF += "0\nSECTION\n  2\nHEADER\n  9\n$ACADVER\n  1\nAC1006\n  0\nENDSEC\n  0\n";
        //layers:
        strDXF += "SECTION\n  2\nTABLES\n  0\nTABLE\n2\n";
        strDXF += this.getLayersString();
        strDXF += "ENDTAB\n 0\nENDSEC\n";
        return strDXF;
    };
    /**
     * 
     * @returns {String}
     */
    this.getBodyString = function() {
        var strDXF = "";
        strDXF += "0\nSECTION\n2\nENTITIES\n0\n";
        strDXF += this.getShapeString();
        strDXF += "ENDSEC\n0\nEOF\n";
        return strDXF;
    };
    /**
     * 
     * @returns {String}
     */
    this.getLayersString = function()
    {
        var strDXF = "";
        strDXF += "LAYER\n  0\n";
        var count = 1;
        for (var i in this.layers)
        {
            var layer = this.layers[i];
            strDXF += "LAYER\n 2\n" + layer.name + "\n 70\n 64\n 62\n " + layer.color + "\n 6\n" + layer.linetype + "\n 0\n";
            count++;
        }
        return strDXF;
    };
    /**
     * 
     * @returns {unresolved}
     */
    this.getShapeString = function() {
        return this.ShapeString;
    };
    /**
     * 
     * @param {type} x
     * @param {type} y
     * @param {type} z
     * @param {type} x2
     * @param {type} y2
     * @param {type} z2
     * @param {type} layerName
     * @param {type} color
     * @returns {String}
     */
    this.addLine = function(x, y, z, x2, y2, z2, layerName, color)
    {
        layerName = (typeof(layerName) !== 'undefined') ? layerName : "0";
        color = (typeof(color) !== 'undefined') ? color : "8";

        z = (typeof(z) !== undefined) ? z : "0";
        var str = "LINE\n" +
                "8" + "\n" +
                layerName + "\n" +
                "10" + "\n" +
                x + "\n" +
                "20" + "\n" +
                y + "\n" +
                "30" + "\n" +
                z + "\n" +
                "11" + "\n" +
                x2 + "\n" +
                "21" + "\n" +
                y2 + "\n" +
                "31" + "\n" +
                z2 + "\n0\n";
        this.ShapeString += str;
        return str;
    };
    /**
     * 
     * @param {type} x
     * @param {type} y
     * @param {type} z
     * @param {type} text
     * @param {type} size
     * @param {type} layerName
     * @param {type} color
     * @returns {String}
     */
    this.addText = function(x, y, z, text, size, layerName, color) {
        size = (typeof(size) !== 'undefined') ? size : 1;
        text = (typeof(text) !== 'undefined') ? text : "";
        layerName = (typeof(layerName) !== 'undefined') ? layerName : "0";
        color = (typeof(color) !== 'undefined') ? color : "8";
        var str = "TEXT\n" +
                "8" + "\n" +
                layerName + "\n" +
                " 10\n" +
                x + "\n" +
                " 20\n" +
                y + "\n" +
                " 30\n" +
                z + "\n" +
                " 40\n" +
                size + "\n" +
                "  1\n" +
                text + "\n" +
                "  0\n";
        this.ShapeString += str;
        return str;
    };

    this.addCircle = function(x, y, z, radius, layerName, color)
    {
        /*CIRCLE
         8
         PUNTI
         10
         3.99
         20
         2.80
         30
         0.00
         40
         0.2
         0*/
       
        layerName = (typeof(layerName) !== 'undefined') ? layerName : "0";
        color = (typeof(color) !== 'undefined') ? color : "8";

        z = (typeof(z) !== undefined) ? z : "0";
        var str = "CIRCLE\n" +
                "8" + "\n" +
                layerName + "\n" +
                "10" + "\n" +
                x + "\n" +
                "20" + "\n" +
                y + "\n" +
                "30" + "\n" +
                z + "\n" +
                "40" + "\n" +
                radius + "\n" +
                "0\n";
        this.ShapeString += str;
        return str;
    };
}
